// Copyright (c) 2021 The Foundry Visionmongers Ltd. All Rights Reserved.

#ifndef CRYPTOMATTELAYERDIALOG_MOC_H
#define CRYPTOMATTELAYERDIALOG_MOC_H

#include <QtWidgets/QDialog>

namespace DD {
  namespace Image {
    class LayerI;
  }
}

class QDialogButtonBox;
class QLineEdit;
class QWidget;

namespace Foundry {
  namespace Encryptomatte {

    // This class is a GUI element (widget) responsible for the pop-up
    // dialog of creating a new cryptomatte layer.
    class CryptomatteLayerDialog : public QDialog
    {
      Q_OBJECT

    public:
      // Constructs the dialog with the cryptomatte layer name provided
      // defaulting to a reasonable value. This string is displayed in the
      // input field when the dialog opens up.
      CryptomatteLayerDialog(std::string cryptoLayerName = "CryptoLayer", QWidget* parent = nullptr);

      // Returns the cryptomatte layer name from the input field of the
      // dialog. This is typically entered by the user.
      std::string cryptomatteLayerName() const { return _cryptomatteLayerName; }

    private:
      // Displays the error message in a popup dialog
      void displayErrorMessage(const std::string& errorMessage);

      // Override from the base class. This method is responsible for
      // implementing the logic when the user clicks on the OK press
      // button.
      void accept() override;

      // Override from the base class with some reasonable size hint
      // values.
      QSize sizeHint() const override { return {400, 120}; }

      // The usual OK and Cancel buttons that one would expect from a standard
      // pop-up dialog.
      QDialogButtonBox* _okCancelButtonBox;

      // The main input field of the dialog where the cryptomatte layer
      // name is entered by the user.
      QLineEdit* _lineEditName;

      // This is the value of the input field in the dialog, typically
      // entered by the user.
      std::string _cryptomatteLayerName;

      // This is the underlying cryptomatte layers with the digit suffixes
      // (i.e. CryptoObject00/01/02).
      std::vector<DD::Image::LayerI*> _layers;
    };

  }
}

#endif
