// Copyright (c) 2021 The Foundry Visionmongers Ltd. All Rights Reserved.

#ifndef CRYPTOMATTELAYERWIDGET_MOC_H
#define CRYPTOMATTELAYERWIDGET_MOC_H

#include "DDImage/Knob.h"

#include <QtWidgets/QWidget>

class QHBoxLayout;
class QMenu;
class QToolButton;

namespace Foundry {

  namespace Encryptomatte {

    class CryptomatteLayer_Knob;

    // The GUI element for the cryptomatte layer knob with a drop-down list.
    // This class is the view part of the view-controller architecture of knobs.
    class CryptomatteLayerWidget : public QWidget
    {
      Q_OBJECT
    public:
      // Constructs the widget.
      CryptomatteLayerWidget(CryptomatteLayer_Knob* knob);
      ~CryptomatteLayerWidget() override;

      // This method is called when the widget gets created.
      void buildGroup();

      // This method is responsible for updating the visuals of the knob,
      // basically updating the currently selected cryptomatte layer.
      void update();

      // This method populates the drop-down list of the knob with all the
      // available options.
      void populateMenu();

      // This methods displays and handles the new layer selection dialog.
      void showNewCryptomatteLayerDialog();

      void childDestroyed(QObject* destroyedObject);

    private:
      // Adjusts the width of the tool button to the length of the longest
      // entry in the drop-down list.
      void adjustWidthToContents();

      // Generic callback for various events that can happen for the widget.
      static int WidgetCallback(void* closure, DD::Image::Knob::CallbackReason reason);

      QHBoxLayout* _layout;
      QToolButton* _layerChoice;
      QMenu* _layerMenu;

      CryptomatteLayer_Knob* _knob;
    };
  }
}

#endif
