// codecWhitelist.h
// Copyright (c) 2014 The Foundry Visionmongers Ltd.  All Rights Reserved.

#ifndef NUKE_PLUGINS_FILEIO_CODECWHITELIST_H
#define NUKE_PLUGINS_FILEIO_CODECWHITELIST_H

#include <string>

namespace Foundry
{
namespace Nuke
{

//! Check whether a named container format is Whitelisted
bool isFormatWhitelistedForReading(const char* name);
bool isFormatWhitelistedForWriting(const char* name);

//! Check whether a certain codec name is Whitelisted
bool isCodecWhitelistedForReading(const char* name, std::string& outReason);
bool isCodecWhitelistedForWriting(const char* name, std::string& outReason);

// Get the codec's long name, if it has been overriden.
// Used to match ffmpeg code names to Quicktime's.
// Should move to Simon's ffmpeg shared header when available.
const char* getCodecOverridenLongName(const char* shortName);
  
// Get the codec's knob label.
// Used to match ffmpeg fourccs and code names to Quicktime's.
// Should move to Simon's ffmpeg shared header when available.
const char* getCodecKnobLabel(const char* shortName);

const char* getMov64CodecTranslationScript();
const char* getMetaCodecTranslationScript();
  
} // namespace Nuke
} // namespace Foundry

#endif // NUKE_PLUGINS_FILEIO_CODECWHITELIST_H

