////////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2014 The Foundry Visionmongers Ltd.  All Rights Reserved.
////////////////////////////////////////////////////////////////////////////////

// This file contains code which is common to mov64Reader & mov64Writer.

#ifndef NUKE_MOV64COMMON_H
#define NUKE_MOV64COMMON_H

#include <string>
#include <vector>

extern "C" {
  #include <errno.h>
  #include <libavcodec/avcodec.h>
  #include <libavutil/error.h>
}

// String array returned by EnumerationKnobI::menu. Here so mov64 reader/writer
// can include movCommon.
typedef std::vector<std::string> StringArray;

////////////////////////////////////////////////////////////////////////////////
// NCLC static names and mappings.
////////////////////////////////////////////////////////////////////////////////

//Used in ffmpeg metadata dicts to stash values written to and from nclc atom.
static const char kNCLCPrimariesKey[]   = "fn_primaries";
static const char kNCLCTransferKey[]    = "fn_transfer_function";
static const char kNCLCMatrixKey[]      = "fn_matrix";

//Labels used in a batch of places.
static const char kNCLCUnknownLabel[]       = "Unknown";
static const char kNCLCUnspecifiedLabel[]   = "Unspecified";
static const char kNCLCReservedLabel[]      = "Reserved";

static const std::vector<const char*> kNCLCPrimariesLabel = {
  kNCLCReservedLabel,
  "ITU-R BT.709",
  kNCLCUnspecifiedLabel,
  kNCLCReservedLabel,
  "ITU-R BT.470M",
  "ITU-R BT.470BG",
  "SMPTE 170M",
  "SMPTE 240M",
  "FILM",
  "ITU-R BT.2020",
  "SMPTE ST 428-1",
  "DCI P3",
  "P3 D65"
};

static const std::vector<const char*> kNCLCTransferLabel = {
  kNCLCReservedLabel,
  "ITU-R BT.709",
  kNCLCUnspecifiedLabel,
  kNCLCReservedLabel,
  "Gamma 2.2 curve",
  "Gamma 2.8 curve",
  "SMPTE 170M",
  "SMPTE 240M",
  "Linear",
  "Log",
  "Log Sqrt",
  "IEC 61966-2-4",
  "ITU-R BT.1361 Extended Colour Gamut",
  "IEC 61966-2-1",
  "ITU-R BT.2020 10 bit",
  "ITU-R BT.2020 12 bit",
  "SMPTE ST 2084 (PQ)",
  "SMPTE ST 428-1",
  "ARIB STD-B67 (HLG)"
};

static const std::vector<const char*> kNCLCMatrixLabel = {
  "GBR",
  "BT709",
  kNCLCUnspecifiedLabel,
  kNCLCReservedLabel,
  "FCC",
  "BT470BG",
  "SMPTE 170M",
  "SMPTE 240M",
  "YCOCG",
  "BT2020 Non-constant Luminance",
  "BT2020 Constant Luminance"
};

// Avid DNxHD specific. Label for switching between video legal and full range.
static const char kARESCompressionID[]  = "fn_ares_compression_id";
static const char kACLRYuvRange[]       = "fn_aclr_yuv_range";

////////////////////////////////////////////////////////////////////////////////
// Chunksize static names.
////////////////////////////////////////////////////////////////////////////////

static const char kChunkSizeKey[]      = "fn_log2chunksize";

////////////////////////////////////////////////////////////////////////////////
// These are the codec profile names used by Apple and
// so are used here in the FFmpeg reader/writer to
// clearly identify a specific ProRes encoding. This
// is done as FFmpeg identifies all ProRes encoding
// profiles with the name 'prores'.

#define APPLE_PRORES_4444XQ_NAME "Apple ProRes 4444 XQ"
#define APPLE_PRORES_4444_NAME "Apple ProRes 4444"
#define APPLE_PRORES_422HQ_NAME "Apple ProRes 422 HQ"
#define APPLE_PRORES_422_NAME "Apple ProRes 422"
#define APPLE_PRORES_422LT_NAME "Apple ProRes 422 LT"
#define APPLE_PRORES_422PROXY_NAME "Apple ProRes 422 Proxy"

////////////////////////////////////////////////////////////////////////////////
// Macros for endian swapping.
#define SWAP16(x) ((((x) & 0xff00) >> 8) | (((x) & 0x00ff) << 8))
#define SWAP32(x) ((((x) & 0xff000000) >> 24) | (((x) & 0x00ff0000) >> 8) | (((x) & 0x0000ff00) << 8) | (((x) &0x000000ff) << 24))


int mov64_av_encode(AVCodecContext* avctx, AVPacket* pkt, const AVFrame* frame, int* got_packet);
int mov64_av_decode(AVCodecContext* avctx, AVFrame* frame, int* got_frame, const AVPacket & pkt);

#endif // NUKE_MOV64COMMON_H
